@@ -1,7 +1,7 @@
 from typing import Union
-import requests
 import traitlets
 import ipywidgets as ipw
+import requests
 
 try:
     from simplejson import JSONDecodeError
@@ -15,15 +15,18 @@ from optimade.models.utils import CHEMICAL_SYMBOLS, SemanticVersion
 from optimade_client.exceptions import BadResource, QueryError
 from optimade_client.logger import LOGGER
 from optimade_client.subwidgets import (
-    StructureDropdown,
     FilterTabs,
     ResultsPageChooser,
+    StructureDropdown,
 )
 from optimade_client.utils import (
-    perform_optimade_query,
-    handle_errors,
-    TIMEOUT_SECONDS,
+    ButtonStyle,
     check_entry_properties,
+    handle_errors,
+    ordered_query_url,
+    perform_optimade_query,
+    SESSION,
+    TIMEOUT_SECONDS,
 )
 
 
@@ -47,8 +50,26 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
         traitlets.Instance(LinksResourceAttributes, allow_none=True),
     )
 
-    def __init__(self, result_limit: int = None, **kwargs):
+    def __init__(
+        self,
+        result_limit: int = None,
+        button_style: Union[ButtonStyle, str] = None,
+        **kwargs,
+    ):
         self.page_limit = result_limit if result_limit else 10
+        if button_style:
+            if isinstance(button_style, str):
+                button_style = ButtonStyle[button_style.upper()]
+            elif isinstance(button_style, ButtonStyle):
+                pass
+            else:
+                raise TypeError(
+                    "button_style should be either a string or a ButtonStyle Enum. "
+                    f"You passed type {type(button_style)!r}."
+                )
+        else:
+            button_style = ButtonStyle.PRIMARY
+
         self.offset = 0
         self.number = 1
         self._data_available = None
@@ -66,7 +87,7 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
 
         self.query_button = ipw.Button(
             description="Search",
-            button_style="primary",
+            button_style=button_style.value,
             icon="search",
             disabled=True,
             tooltip="Search - No database chosen",
@@ -364,10 +385,15 @@ class OptimadeQueryFilterWidget(  # pylint: disable=too-many-instance-attributes
         # If a complete link is provided, use it straight up
         if link is not None:
             try:
-                response = requests.get(link, timeout=TIMEOUT_SECONDS).json()
+                link = ordered_query_url(link)
+                response = SESSION.get(link, timeout=TIMEOUT_SECONDS)
+                if response.from_cache:
+                    LOGGER.debug("Request to %s was taken from cache !", link)
+                response = response.json()
             except (
                 requests.exceptions.ConnectTimeout,
                 requests.exceptions.ConnectionError,
+                requests.exceptions.ReadTimeout,
             ) as exc:
                 response = {
                     "errors": {
